@@ -12,7 +12,9 @@ from copy import deepcopy
 import re
 import sys
 
-from deepops import deepremoveitems, deepmerge, deepdiff, deepsetdefault, deepget
+from deepops import (
+    deepdiff, deepfilter, deepget, deepmerge, deepremoveitems, deepsetdefault)
+
 import yaml
 
 
@@ -65,14 +67,27 @@ class DiffConvert:
     and the update() method would return the commands required to change
     it to the new value.
 
-    The child classes will override the following values:
+    The 'context', 'cmd' and 'ext' parameters, below, are all tuples
+    giving parts of the path through the keys of the configuration
+    dictionary to match for the specific converter.  These can be
+    literal keys, or the value None, if that level of the path is a
+    wildcard match for all keys - for example, '("interface", None)' to
+    match all interfaces.  The part of the configuration dictionary
+    that matches the 'context + cmd' parts of the path will be passed
+    as the 'cfg' and 'diff' parameters to the action methods.
 
-    path -- a tuple giving the path of keys through the dictionaries to
-    match for these actions; these can be literal keys or the value
-    None, if that level of the path is to wildcard match all keys (for
-    example, all interfaces); the part of the configuration dictionary
-    that matches this path will be passed as the 'cfg' and 'diff'
-    parameters to the action functions
+    The child classes can override the following values:
+
+    context -- the path to the context containing the commands used in
+    this conversion: if this context is removed in its entirety, the
+    remove() action for this converter will not be called as the
+    removal of the context will remove it; this variable defaults to
+    the empty tuple, for a command at the top level
+
+    cmd -- the path for this command in the configuration, following
+    the context; this part of the dictionary will be passed in the
+    'cfg' and 'diff' parameters to the action methods; this variable
+    defaults to None and must be defined by a child class
 
     ext -- an extension to path which must be matched, but this part is
     not used to further specify the part of the dictionaries passed to
@@ -95,7 +110,8 @@ class DiffConvert:
     """
 
 
-    path = None
+    context = tuple()
+    cmd = None    # leave as None to cause an error if not defined in child
     ext = tuple()
     name = None
     insert_before = None
@@ -106,22 +122,81 @@ class DiffConvert:
         the repeated processing of the converter matches.
         """
 
-        # store the full path, including the extension
-        self.path_full = self.path + self.ext
-
-        # store the number of elements in the path
-        self.path_len = len(self.path)
+        # calculate and store a few things, for efficiency
+        self._path_full = self.context + self.cmd + self.ext
+        self._context_len = len(self.context)
+        self._path_len = len(self.context + self.cmd)
 
         # store the set of indices of wildcard elements of the path (we
         # need these to get the argument list to pass to the converter
         # action methods)
         self.wildcard_indices = {
-            i for i, v in enumerate(self.path_full) if v is None }
+            i for i, v in enumerate(self._path_full) if v is None }
 
 
-    def pathmatches(self, d):
+    def _pathmatches(self, d, path):
+        """This function is used to recursively step along the
+        paths.
+        """
+
+        # if the path is finished, return a single result with an
+        # empty list, as there are no more path elements
+        #
+        # note that this is different from an empty list (which
+        # would mean no matches
+        if not path:
+            return [ [] ]
+
+        # get the path head and tail to make things easier to read
+        path_head, path_tail = path[0], path[1:]
+
+        # if this element is not a type we can iterate or search
+        # through (we've perhaps reached a value or a None), or the
+        # dictionary is empty, there are no matches, so just return
+        # an empty list (which will cause all higher levels in the
+        # path that matched to be discarded, giving no resulsts)
+        if not isinstance(d, (dict, list, set)) or (not d):
+            return []
+
+        # if the path element is None, we're doing a wildcard match
+        if path_head is None:
+            # initialise an empty list for all returned matching
+            # results
+            results = []
+
+            # go through all the keys at this level in the dictonary
+            for d_key in d:
+                # are there levels below this one?
+                if path_tail:
+                    # yes - recursively get the matches from under
+                    # this key
+                    for matches in self._pathmatches(d[d_key], path_tail):
+                        # add this match to the list of matches,
+                        # prepending this key onto the start of the
+                        # path
+                        results.append([d_key] + matches)
+                else:
+                    # no - just add this result (this is a minor
+                    # optimisation, as well as avoiding an error by
+                    # trying to index into a non-dict type), above
+                    results.append([d_key])
+
+            return results
+
+        # we have a literal key to match - if it's found,
+        # recursively get the matches under this level
+        if path_head in d:
+            return [ ([path_head] + matches)
+                            for matches
+                            in self._pathmatches(d[path_head], path_tail) ]
+
+        # we have no matches, return the empty list
+        return []
+
+
+    def full_matches(self, d):
         """This method takes a dictionary and returns any matches for
-        the path in it, as a list of paths; each path is, itself, a
+        the full path in it, as a list of paths; each path is, itself, a
         list of keys.
 
         If any of the elements of the path are None, this is treated as
@@ -134,74 +209,43 @@ class DiffConvert:
         particular order.
         """
 
+        return self._pathmatches(d, self._path_full)
 
-        def _pathmatches(d, path):
-            """This function is used to recursively step along the
-            paths.
-            """
 
-            # if the path is finished, return a single result with an
-            # empty list, as there are no more path elements
-            #
-            # note that this is different from an empty list (which
-            # would mean no matches
-            if not path:
-                return [ [] ]
+    def context_removed(self, d, match):
+        """This method take a remove dictionary, as returned by
+        deepdiff(), and a specific match into it (which must be from
+        the same DiffConvert object as the method is called on) and
+        returns True iff the context for this converter is in it
+        entirely and exactly.
+        """
 
-            # get the path head and tail to make things easier to read
-            path_head, path_tail = path[0], path[1:]
+        # if this converter has no containing context, we definitely
+        # can't be removing it, so will need to remove this item
+        if not self.context:
+            return False
 
-            # if this element is not a type we can iterate or search
-            # through (we've perhaps reached a value or a None), or the
-            # dictionary is empty, there are no matches, so just return
-            # an empty list (which will cause all higher levels in the
-            # path that matched to be discarded, giving no resulsts)
-            if not isinstance(d, (dict, list, set)) or (not d):
-                return []
+        # get the part of the match fitting the context for this
+        # converter
+        match_context = match[0 : self._context_len]
 
-            # if the path element is None, we're doing a wildcard match
-            if path_head is None:
-                # initialise an empty list for all returned matching
-                # results
-                results = []
-
-                # go through all the keys at this level in the dictonary
-                for d_key in d:
-                    # are there levels below this one?
-                    if path_tail:
-                        # yes - recursively get the matches from under
-                        # this key
-                        for matches in _pathmatches(d[d_key], path_tail):
-                            # add this match to the list of matches,
-                            # prepending this key onto the start of the
-                            # path
-                            results.append([d_key] + matches)
-                    else:
-                        # no - just add this result (this is a minor
-                        # optimisation, as well as avoiding an error by
-                        # trying to index into a non-dict type), above
-                        results.append([d_key])
-
-                return results
-
-            # we have a literal key to match - if it's found,
-            # recursively get the matches under this level
-            if path_head in d:
-                return [ ([path_head] + matches)
-                             for matches
-                             in _pathmatches(d[path_head], path_tail) ]
-
-            # we have no matches, return the empty list
-            return []
-
-        # start mathcing with the full path
-        return _pathmatches(d, self.path_full)
+        # see if the context is matched in its entirety in the remove
+        # dictionary - if it's not empty, or we get an error doing it,
+        # we're not removing the context
+        #
+        # KeyError indicates item not found; TypeError if level is not
+        # a dictionary
+        try:
+            return deepget(d, *match_context, default_error=True) is None
+        except (KeyError, TypeError):
+            return False
 
 
     def remove(self, cfg, diff, args):
         """The remove() method is called when the specified path is in
         the remove differences (i.e. it's in the 'from' configuration
-        but not in the 'to' configuration).
+        but not in the 'to' configuration), unless the containing
+        context is being removed in its entirety.
 
         Keyword arguments:
 
@@ -260,6 +304,14 @@ class DiffConvert:
         pass
 
 
+    def get_path(self):
+        """Get the non-extended path for this converter (i.e. the
+        'context' and 'cmd' paths joined, excluding the 'ext').
+        """
+
+        return self.context + self.cmd
+
+
     def get_cfg(self, cfg, match):
         """This method returns the configuration to be passed to the
         converter's action methods [remove() and update()].
@@ -276,7 +328,7 @@ class DiffConvert:
 
         # try to get the specified matching path
         try:
-            return deepget(cfg, *match[0 : self.path_len])
+            return deepget(cfg, *match[0 : self._path_len])
 
         except TypeError:
             # we got a TypeError so make the assumption that we've hit
@@ -321,7 +373,7 @@ class DiffConfig:
 
 
     def __init__(self, init_explain=False, init_debug_config=False,
-                       init_debug_diff=False, init_debug_convert=0):
+                 init_debug_diff=False, init_debug_convert=0):
 
         """The constructor initialises the exclude list to empty and
         adds and converters using _add_converters().  It also stores
@@ -594,14 +646,25 @@ class DiffConfig:
         # use deepdiff() to work out the differences between the two
         # configuration dictionaries - what must be removed and what
         # needs to be added or updated
+        #
+        # then use deepfilter() to get the full details of each item
+        # being removed, rather than just the top of a subtree being
+        # removed
 
         remove_cfg, update_cfg = deepdiff(from_cfg, to_cfg)
+        remove_cfg_full = deepfilter(from_cfg, remove_cfg)
+
 
         if self._debug_diff:
             print("=> differences - remove:",
                   yaml.dump(remove_cfg, default_flow_style=False),
+
+                  "=> differences - remove full:",
+                  yaml.dump(remove_cfg_full, default_flow_style=False),
+
                   "=> differences - update (add/change):",
                   yaml.dump(update_cfg, default_flow_style=False),
+
                   sep="\n", file=sys.stderr)
 
 
@@ -616,7 +679,8 @@ class DiffConfig:
         for cvtr in self._cvtrs:
             if self._debug_convert:
                 print(">> checking difference:",
-                      pathstr([ "*" if i is None else i for i in cvtr.path ]),
+                      pathstr([ "*" if i is None else i
+                                    for i in cvtr.get_path() ]),
                       "name:", cvtr.name, file=sys.stderr)
 
 
@@ -626,9 +690,12 @@ class DiffConfig:
             # we do this rather than processing each list one after the
             # other so we combine removes and updates on the same part
             # of the configuration together
+            #
+            # we combine them by manually building a list, rather than
+            # using a set as a set requires hashable types
 
-            remove_matches = cvtr.pathmatches(remove_cfg)
-            update_matches = cvtr.pathmatches(update_cfg)
+            remove_matches = cvtr.full_matches(remove_cfg_full)
+            update_matches = cvtr.full_matches(update_cfg)
 
             all_matches = []
             for match in sorted(remove_matches + update_matches):
@@ -636,8 +703,6 @@ class DiffConfig:
                     all_matches.append(match)
 
 
-            # go through all matches
-
             for match in all_matches:
                 # handle REMOVE conversions, if matching
 
@@ -648,6 +713,19 @@ class DiffConfig:
                               file=sys.stderr)
 
 
+                    # if we're removing the entire context for this
+                    # match, we don't need to do it, as that will
+                    # remove this, while it's at it
+
+                    if cvtr.context_removed(remove_cfg, match):
+                        if self._debug_convert:
+                            print(
+                                "-> containing context being removed - skip",
+                                file=sys.stderr)
+
+                        continue
+
+
                     # get elements in the path matching wildcards
 
                     args = cvtr.get_wildcard_args(match)
@@ -662,12 +740,11 @@ class DiffConfig:
                     cvtr_diff = cvtr.get_cfg(remove_cfg, match)
 
                     if self._debug_convert >= 2:
-                        print("-> from configuration:",
-                            yaml.dump(
-                                cvtr_cfg, default_flow_style=False),
+                        print(
+                            "-> from configuration:",
+                            yaml.dump(cvtr_cfg, default_flow_style=False),
                             "-> remove configuration:",
-                            yaml.dump(
-                                cvtr_diff, default_flow_style=False),
+                            yaml.dump(cvtr_diff, default_flow_style=False),
                             sep="\n", file=sys.stderr)
 
 
@@ -733,12 +810,11 @@ class DiffConfig:
                     cvtr_diff = cvtr.get_cfg(update_cfg, match)
 
                     if self._debug_convert >= 2:
-                        print("-> to configuration:",
-                            yaml.dump(
-                                cvtr_cfg, default_flow_style=False),
+                        print(
+                            "-> to configuration:",
+                            yaml.dump(cvtr_cfg, default_flow_style=False),
                             "-> update configuration:",
-                            yaml.dump(
-                                cvtr_diff, default_flow_style=False),
+                            yaml.dump(cvtr_diff, default_flow_style=False),
                             sep="\n", file=sys.stderr)
 
 
