@@ -90,7 +90,7 @@ _cvtrs = []
 
 
 class _Cvtr_Hostname(DiffConvert):
-    path = "hostname",
+    cmd = "hostname",
 
     def remove(self, cfg, diff, args):
         return "no hostname"
@@ -107,7 +107,7 @@ _cvtrs.append(_Cvtr_Hostname)
 
 
 class _Cvtr_Int(DiffConvert):
-    path = "interface", None
+    cmd = "interface", None
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -128,11 +128,16 @@ class _Cvtr_Int(DiffConvert):
 _cvtrs.append(_Cvtr_Int)
 
 
+class _DiffCvtr_Int(DiffConvert):
+    "Abstract class for interface context converters to subclass."
+    context = "interface", None
+
+
 # we put the 'interface / shutdown' at the start to shut it down before
 # we do any [re]configuration
 
-class _Cvtr_Int_Shutdown(DiffConvert):
-    path = "interface", None, "shutdown"
+class _Cvtr_Int_Shutdown(_DiffCvtr_Int):
+    cmd = "shutdown",
     name = "shutdown"
 
     def update(self, cfg, diff, args):
@@ -142,8 +147,8 @@ class _Cvtr_Int_Shutdown(DiffConvert):
 _cvtrs.append(_Cvtr_Int_Shutdown)
 
 
-class _Cvtr_Int_CDPEna(DiffConvert):
-    path = "interface", None, "cdp-enable"
+class _Cvtr_Int_CDPEna(_DiffCvtr_Int):
+    cmd = "cdp-enable",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -154,13 +159,14 @@ class _Cvtr_Int_CDPEna(DiffConvert):
 
     def update(self, cfg, diff, args):
         name, = args
-        return "interface " + name, " %scdp enable" % ("" if cfg else "no ")
+        return ("interface " + name,
+                " " + ("" if cfg else "no ") + "cdp enable")
 
-#_cvtrs.append(_Cvtr_Int_CDPEna)
+_cvtrs.append(_Cvtr_Int_CDPEna)
 
 
-class _Cvtr_Int_ChnGrp(DiffConvert):
-    path = "interface", None, "channel-group"
+class _Cvtr_Int_ChnGrp(_DiffCvtr_Int):
+    cmd = "channel-group",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -175,8 +181,8 @@ class _Cvtr_Int_ChnGrp(DiffConvert):
 _cvtrs.append(_Cvtr_Int_ChnGrp)
 
 
-class _Cvtr_Int_Desc(DiffConvert):
-    path = "interface", None, "description"
+class _Cvtr_Int_Desc(_DiffCvtr_Int):
+    cmd = "description",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -189,8 +195,8 @@ class _Cvtr_Int_Desc(DiffConvert):
 _cvtrs.append(_Cvtr_Int_Desc)
 
 
-class _Cvtr_Int_Encap(DiffConvert):
-    path = "interface", None, "encap"
+class _Cvtr_Int_Encap(_DiffCvtr_Int):
+    cmd = "encapsulation",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -203,16 +209,18 @@ class _Cvtr_Int_Encap(DiffConvert):
 _cvtrs.append(_Cvtr_Int_Encap)
 
 
-class _Cvtr_Int_IPAccGrp(DiffConvert):
-    path = "interface", None, "ip-access-group"
+class _Cvtr_Int_IPAccGrp(_DiffCvtr_Int):
+    cmd = "ip-access-group",
 
     def remove(self, cfg, diff, args):
         name, = args
         l = ["interface " + name]
+
         # if there are differences, just removed the specific group(s);
         # if the whole block is gone, remove all groups there before
         for dir in sorted(diff if diff else cfg):
             l.append(" no ip access-group " + dir)
+
         return l
 
     def update(self, cfg, diff, args):
@@ -225,8 +233,8 @@ class _Cvtr_Int_IPAccGrp(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPAccGrp)
 
 
-class _Cvtr_Int_IPAddr(DiffConvert):
-    path = "interface", None, "ip-addr"
+class _Cvtr_Int_IPAddr(_DiffCvtr_Int):
+    cmd = "ip-address",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -239,12 +247,12 @@ class _Cvtr_Int_IPAddr(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPAddr)
 
 
-class _Cvtr_Int_IPAddrSec(DiffConvert):
-    path = "interface", None, "ip-addr-sec"
+class _Cvtr_Int_IPAddrSec(_DiffCvtr_Int):
+    cmd = "ip-address-secondary",
 
     def remove(self, cfg, diff, args):
         name, = args
-        l = ["interface %s" % name]
+        l = ["interface " + name]
         for addr in sorted(diff if diff else cfg):
             l.append(" no ip address %s secondary" % addr)
         return l
@@ -259,8 +267,8 @@ class _Cvtr_Int_IPAddrSec(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPAddrSec)
 
 
-class _Cvtr_Int_IPHlp(DiffConvert):
-    path = "interface", None, "ip-helper-addr"
+class _Cvtr_Int_IPHlp(_DiffCvtr_Int):
+    cmd = "ip-helper-address",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -280,8 +288,8 @@ class _Cvtr_Int_IPHlp(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPHlp)
 
 
-class _Cvtr_Int_IP6Addr(DiffConvert):
-    path = "interface", None, "ipv6-address"
+class _Cvtr_Int_IP6Addr(_DiffCvtr_Int):
+    cmd = "ipv6-address",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -300,8 +308,8 @@ class _Cvtr_Int_IP6Addr(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IP6Addr)
 
 
-class _Cvtr_Int_IPIGMPVer(DiffConvert):
-    path = "interface", None, "ip-igmp-ver"
+class _Cvtr_Int_IPIGMPVer(_DiffCvtr_Int):
+    cmd = "ip-igmp-version",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -314,8 +322,8 @@ class _Cvtr_Int_IPIGMPVer(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPIGMPVer)
 
 
-class _Cvtr_Int_IPMcastBdry(DiffConvert):
-    path = "interface", None, "ip-mcast-bdry"
+class _Cvtr_Int_IPMcastBdry(_DiffCvtr_Int):
+    cmd = "ip-multicast-boundary",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -328,8 +336,8 @@ class _Cvtr_Int_IPMcastBdry(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPMcastBdry)
 
 
-class _Cvtr_Int_IPPIMMode(DiffConvert):
-    path = "interface", None, "ip-pim", "mode"
+class _Cvtr_Int_IPPIMMode(_DiffCvtr_Int):
+    cmd = "ip-pim", "mode"
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -342,8 +350,8 @@ class _Cvtr_Int_IPPIMMode(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPPIMMode)
 
 
-class _Cvtr_Int_IPPIMBSRBdr(DiffConvert):
-    path = "interface", None, "ip-pim", "bsr-border"
+class _Cvtr_Int_IPPIMBSRBdr(_DiffCvtr_Int):
+    cmd = "ip-pim", "bsr-border"
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -356,8 +364,8 @@ class _Cvtr_Int_IPPIMBSRBdr(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IPPIMBSRBdr)
 
 
-class _Cvtr_Int_ServPol(DiffConvert):
-    path = "interface", None, "service-policy"
+class _Cvtr_Int_ServPol(_DiffCvtr_Int):
+    cmd = "service-policy",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -376,8 +384,23 @@ class _Cvtr_Int_ServPol(DiffConvert):
 _cvtrs.append(_Cvtr_Int_ServPol)
 
 
-class _Cvtr_Int_StandbyIP(DiffConvert):
-    path = "interface", None, "standby", None, "ip"
+class _Cvtr_Int_StandbyVer(_DiffCvtr_Int):
+    context = "interface", None
+    cmd = "standby", "version"
+
+    def remove(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " no standby version"
+
+    def update(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " standby version %d" % diff
+
+_cvtrs.append(_Cvtr_Int_StandbyVer)
+
+
+class _Cvtr_Int_StandbyIP(_DiffCvtr_Int):
+    cmd = "standby", "group", None, "ip"
 
     def remove(self, cfg, diff, args):
         name, grp = args
@@ -390,8 +413,8 @@ class _Cvtr_Int_StandbyIP(DiffConvert):
 #_cvtrs.append(_Cvtr_Int_StandbyIP)
 
 
-class _Cvtr_Int_StandbyIPSec(DiffConvert):
-    path = "interface", None, "standby", None, "ip-sec"
+class _Cvtr_Int_StandbyIPSec(_DiffCvtr_Int):
+    cmd = "standby", "group", None, "ip-secondary"
 
     def remove(self, cfg, diff, args):
         name, grp = args
@@ -410,11 +433,11 @@ class _Cvtr_Int_StandbyIPSec(DiffConvert):
 #_cvtrs.append(_Cvtr_Int_StandbyIPSec)
 
 
-class _Cvtr_Int_SwPortTrkNtv(DiffConvert):
+class _Cvtr_Int_SwPortTrkNtv(_DiffCvtr_Int):
     # we just match the interface as we need to look inside it to see if
     # the interface is part of a channel group
-    path = "interface", None
-    ext = "swport-trunk-native",
+    cmd = tuple()
+    ext = "switchport-trunk-native",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -440,11 +463,11 @@ class _Cvtr_Int_SwPortTrkNtv(DiffConvert):
 _cvtrs.append(_Cvtr_Int_SwPortTrkNtv)
 
 
-class _Cvtr_Int_SwPortTrkAlw(DiffConvert):
+class _Cvtr_Int_SwPortTrkAlw(_DiffCvtr_Int):
     # we just match the interface as we need to look inside it to see if
     # the interface is part of a channel group
-    path = "interface", None
-    ext = "swport-trunk-allow",
+    cmd = tuple()
+    ext = "switchport-trunk-allow",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -478,8 +501,8 @@ class _Cvtr_Int_SwPortTrkAlw(DiffConvert):
 _cvtrs.append(_Cvtr_Int_SwPortTrkAlw)
 
 
-class _Cvtr_Int_VRFFwd(DiffConvert):
-    path = "interface", None, "vrf-forwarding"
+class _Cvtr_Int_VRFFwd(_DiffCvtr_Int):
+    cmd = "vrf-forwarding",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -494,8 +517,8 @@ class _Cvtr_Int_VRFFwd(DiffConvert):
 _cvtrs.append(_Cvtr_Int_VRFFwd)
 
 
-class _Cvtr_Int_XConn(DiffConvert):
-    path = "interface", None, "xconnect"
+class _Cvtr_Int_XConn(_DiffCvtr_Int):
+    cmd = "xconnect",
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -511,8 +534,8 @@ _cvtrs.append(_Cvtr_Int_XConn)
 # we put the 'interface / no shutdown' at the end to only enable the
 # interface once it's been correctly [re]configured
 
-class _Cvtr_Int_NoShutdown(DiffConvert):
-    path = "interface", None, "shutdown"
+class _Cvtr_Int_NoShutdown(_DiffCvtr_Int):
+    cmd = "shutdown",
     name = "no-shutdown"
 
     def remove(self, cfg, diff, args):
@@ -528,7 +551,7 @@ _cvtrs.append(_Cvtr_Int_NoShutdown)
 
 
 class _Cvtr_IPACL_Std(DiffConvert):
-    path = "ip-acl-std", None
+    cmd = "ip-access-list-standard", None
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -543,7 +566,7 @@ _cvtrs.append(_Cvtr_IPACL_Std)
 
 
 class _Cvtr_IPACL_Ext(DiffConvert):
-    path = "ip-acl-ext", None
+    cmd = "ip-access-list-extended", None
 
     def remove(self, cfg, diff, args):
         # include the old list commented out, for comparison
@@ -559,7 +582,7 @@ _cvtrs.append(_Cvtr_IPACL_Ext)
 
 
 class _Cvtr_IPV6ACL_Ext(DiffConvert):
-    path = "ipv6-acl", None
+    cmd = "ipv6-access-list", None
 
     def remove(self, cfg, diff, args):
         name, = args
@@ -579,7 +602,7 @@ _cvtrs.append(_Cvtr_IPV6ACL_Ext)
 
 
 class _Cvtr_IPPfxList(DiffConvert):
-    path = "ip-pfx", None
+    cmd = "ip-prefix-list", None
 
     def remove(self, cfg, diff, args):
         # include the old list commented out, for comparison
@@ -595,7 +618,7 @@ _cvtrs.append(_Cvtr_IPPfxList)
 
 
 class _Cvtr_IPV6PfxList(DiffConvert):
-    path = "ipv6-pfx", None
+    cmd = "ipv6-prefix-list", None
 
     def remove(self, cfg, diff, args):
         # include the old list commented out, for comparison
@@ -616,7 +639,7 @@ _cvtrs.append(_Cvtr_IPV6PfxList)
 
 
 class _Cvtr_IPRoute(DiffConvert):
-    path = "ip-route", None
+    cmd = "ip-route", None
 
     def remove(self, cfg, diff, args):
         route, = args
@@ -630,7 +653,7 @@ _cvtrs.append(_Cvtr_IPRoute)
 
 
 class _Cvtr_IP6Route(DiffConvert):
-    path = "ipv6-route", None
+    cmd = "ipv6-route", None
 
     def remove(self, cfg, diff, args):
         route, = args
@@ -649,7 +672,7 @@ _cvtrs.append(_Cvtr_IP6Route)
 
 
 class _Cvtr_NoSTP(DiffConvert):
-    path = "no-stp", None
+    cmd = "no-spanning-tree-vlan", None
 
     def remove(self, cfg, diff, args):
         tag, = args
@@ -665,7 +688,7 @@ _cvtrs.append(_Cvtr_NoSTP)
 
 
 class _Cvtr_STP_Pri(DiffConvert):
-    path = "stp-priority", None
+    cmd = "spanning-tree-vlan-priority", None
 
     def remove(self, cfg, diff, args):
         tag, = args
@@ -684,7 +707,7 @@ _cvtrs.append(_Cvtr_STP_Pri)
 
 
 class _Cvtr_Vlan(DiffConvert):
-    path = "vlan", None
+    cmd = "vlan", None
 
     def remove(self, cfg, diff, args):
         tag, = args
@@ -699,7 +722,8 @@ _cvtrs.append(_Cvtr_Vlan)
 
 
 class _Cvtr_Vlan_Name(DiffConvert):
-    path = "vlan", None, "name"
+    context = "vlan", None
+    cmd = "name",
 
     def remove(self, cfg, diff, args):
         tag, = args
@@ -755,11 +779,11 @@ class CiscoIOSDiffConfig(DiffConfig):
         super().init_excludes()
 
         self._excludes.update({
-            "ip-acl-ext": {
+            "ip-access-list-extended": {
                 "acl-copp-match-igmp": {},
                 "acl-copp-match-pim-data": {},
             },
-            "ipv6-acl": {
+            "ipv6-access-list": {
                 "acl-copp-match-mld": {},
                 "acl-copp-match-ndv6": {},
                 "acl-copp-match-ndv6hl": {},
