@@ -635,7 +635,7 @@ class _Cmd_Int_Encap(_CmdContext_Int):
     def action(self, groups, cfg, params):
         # lower case the encapsulation definition as IOS stores 'dot1q'
         # as 'dot1Q'
-        cfg["encap"] = groups["encap"].lower()
+        cfg["encapsulation"] = groups["encap"].lower()
 
 _cmds.append(_Cmd_Int_Encap)
 
@@ -644,7 +644,7 @@ class _Cmd_Int_HlprAddr(_CmdContext_Int):
     cmd = r"ip helper-address (?P<helper_addr>(global )?\S+)"
 
     def action(self, groups, cfg, params):
-        cfg.setdefault("ip-helper-addr", set()).add(groups["helper_addr"])
+        cfg.setdefault("ip-helper-address", set()).add(groups["helper_addr"])
 
 _cmds.append(_Cmd_Int_HlprAddr)
 
@@ -663,7 +663,7 @@ class _Cmd_Int_IPAddr(_CmdContext_Int):
     cmd = r"ip address (?P<addr>\S+ \S+)"
 
     def action(self, groups, cfg, params):
-        cfg["ip-addr"] = groups["addr"]
+        cfg["ip-address"] = groups["addr"]
 
 _cmds.append(_Cmd_Int_IPAddr)
 
@@ -673,7 +673,7 @@ class _Cmd_Int_IPAddrSec(_CmdContext_Int):
 
     def action(self, groups, cfg, params):
         # secondary address - record it in a list
-        cfg.setdefault("ip-addr-sec", set()).add(groups["addr"])
+        cfg.setdefault("ip-address-secondary", set()).add(groups["addr"])
 
 _cmds.append(_Cmd_Int_IPAddrSec)
 
@@ -684,7 +684,7 @@ class _Cmd_Int_IP6Addr(_CmdContext_Int):
     def action(self, groups, cfg, params):
         # IPv6 addresses involve letters so we lower case for
         # consistency
-        cfg.setdefault("ipv6-addr", set()).add(groups["addr"].lower())
+        cfg.setdefault("ipv6-address", set()).add(groups["addr"].lower())
 
 _cmds.append(_Cmd_Int_IP6Addr)
 
@@ -693,7 +693,7 @@ class _Cmd_Int_IPIGMPVer(_CmdContext_Int):
     cmd = r"ip igmp version (?P<version>\S+)"
 
     def action(self, groups, cfg, params):
-        cfg["ip-igmp-ver"] = groups["version"]
+        cfg["ip-igmp-version"] = groups["version"]
 
 _cmds.append(_Cmd_Int_IPIGMPVer)
 
@@ -702,7 +702,7 @@ class _Cmd_Int_IPMcastBdry(_CmdContext_Int):
     cmd = r"ip multicast boundary (?P<acl>\S+)"
 
     def action(self, groups, cfg, params):
-        cfg["ip-mcast-bdry"] = groups["acl"]
+        cfg["ip-multicast-boundary"] = groups["acl"]
 
 _cmds.append(_Cmd_Int_IPMcastBdry)
 
@@ -753,7 +753,7 @@ class _Cmd_Int_StandbyIP(_CmdContext_Int):
 
     def action(self, groups, cfg, params):
         deepsetdefault(
-            cfg, "standby", int(groups["grp"]))["ip"] = groups["addr"]
+            cfg, "standby", "group", int(groups["grp"]))["ip"] = groups["addr"]
 
 _cmds.append(_Cmd_Int_StandbyIP)
 
@@ -763,12 +763,21 @@ class _Cmd_Int_StandbyIPSec(_CmdContext_Int):
 
     def action(self, groups, cfg, params):
         deepsetdefault(
-            cfg, "standby", int(groups["grp"]), "ip-sec", last=set()).add(
-                groups["addr"])
+            cfg, "standby", "group", int(groups["grp"]), "ip-sec", last=set()
+        ).add(groups["addr"])
 
 _cmds.append(_Cmd_Int_StandbyIPSec)
 
 
+class _Cmd_Int_StandbyVer(_CmdContext_Int):
+    cmd = r"standby version (?P<ver>\d)"
+
+    def action(self, groups, cfg, params):
+        deepsetdefault(cfg, "standby")["version"] = int(groups["ver"])
+
+_cmds.append(_Cmd_Int_StandbyVer)
+
+
 class _Cmd_Int_SwPortTrkNtv(_CmdContext_Int):
     cmd = r"switchport trunk native vlan (?P<vlan>\d+)"
 
@@ -782,7 +791,7 @@ class _Cmd_Int_SwPortTrkAlw(_CmdContext_Int):
     cmd = r"switchport trunk allowed vlan (add )?(?P<vlans>[0-9,-]+)"
 
     def action(self, groups, cfg, params):
-        cfg.setdefault("swport-trunk-allow", set()).update(
+        cfg.setdefault("switchport-trunk-allow", set()).update(
             _expand_set(groups["vlans"]))
 
 _cmds.append(_Cmd_Int_SwPortTrkAlw)
@@ -815,24 +824,26 @@ class _Cmd_ACLStdRule(_Cmd):
     cmd = r"access-list (?P<num>\d{1,2}|1[3-9]\d{2}) (?P<rule>.+)"
 
     def action(self, groups, cfg, params):
-        deepsetdefault(cfg, "ip-acl-std", groups["num"], last=[]).append(
-            groups["rule"])
+        deepsetdefault(
+            cfg, "ip-access-list-standard", groups["num"], last=[]
+            ).append(groups["rule"])
 
 _cmds.append(_Cmd_ACLStdRule)
 
 
 class _Cmd_IPACL_Std(_Cmd):
     cmd = r"ip access-list standard (?P<name>.+)"
-    enter_context = "ip-acl-std"
+    enter_context = "ip-acl_std"
 
     def action(self, groups, cfg, params):
-        return deepsetdefault(cfg, "ip-acl-std", groups["name"], last=[])
+        return deepsetdefault(
+                   cfg, "ip-access-list-standard", groups["name"], last=[])
 
 _cmds.append(_Cmd_IPACL_Std)
 
 
 class _Cmd_IPACL_Std_Rule(_Cmd):
-    context = "ip-acl-std"
+    context = "ip-acl_std"
     cmd = r"(?P<rule>(permit|deny) +.+)"
 
     def action(self, groups, cfg, params):
@@ -845,25 +856,26 @@ class _Cmd_ACLExtRule(_Cmd):
     cmd = r"access-list (?P<num>1\d{2}|2[0-6]\d{2}) (?P<rule>.+)"
 
     def action(self, groups, cfg, params):
-        deepsetdefault(cfg, "ip-acl-ext", groups["num"], last=[]).append(
-            _ipacl_ext_rule_parse(groups["rule"]))
+        deepsetdefault(
+            cfg, "ip-access-list-extended", groups["num"], last=[]
+            ).append(_ipacl_ext_rule_parse(groups["rule"]))
 
 _cmds.append(_Cmd_ACLExtRule)
 
 
 class _Cmd_IPACL_Ext(_Cmd):
     cmd = r"ip access-list extended (?P<name>.+)"
-    enter_context = "ip-acl-ext"
+    enter_context = "ip-acl_ext"
 
     def action(self, groups, cfg, params):
         name = groups["name"]
-        return deepsetdefault(cfg, "ip-acl-ext", name, last=[])
+        return deepsetdefault(cfg, "ip-access-list-extended", name, last=[])
 
 _cmds.append(_Cmd_IPACL_Ext)
 
 
 class _Cmd_IPACL_Ext_Rule(_Cmd):
-    context = "ip-acl-ext"
+    context = "ip-acl_ext"
     cmd = r"(?P<rule>(permit|deny) +.+)"
 
     def action(self, groups, cfg, params):
@@ -909,7 +921,8 @@ class _Cmd_IPPfx(_Cmd):
     def action(self, groups, cfg, params):
         list_ = groups["list"]
 
-        deepsetdefault(cfg, "ip-pfx", list_, last=[]).append(groups["rule"])
+        deepsetdefault(
+            cfg, "ip-prefix-list", list_, last=[]).append(groups["rule"])
 
 _cmds.append(_Cmd_IPPfx)
 
@@ -920,8 +933,8 @@ class _Cmd_IP6Pfx(_Cmd):
     def action(self, groups, cfg, params):
         list_ = groups["list"]
 
-        deepsetdefault(cfg, "ipv6-pfx", list_, last=[]).append(
-            groups["rule"].lower())
+        deepsetdefault(
+            cfg, "ipv6-prefix", list_, last=[]).append(groups["rule"].lower())
 
 _cmds.append(_Cmd_IP6Pfx)
 
@@ -960,7 +973,9 @@ class _Cmd_NoSTP(_Cmd):
     cmd = r"no spanning-tree vlan (?P<tags>[-0-9,]+)"
 
     def action(self, groups, cfg, params):
-        cfg.setdefault("no-stp", set()).update(_expand_set(groups["tags"]))
+        cfg.setdefault(
+            "no-spanning-tree-vlan", set()
+            ).update(_expand_set(groups["tags"]))
 
 _cmds.append(_Cmd_NoSTP)
 
@@ -971,7 +986,7 @@ class _Cmd_STPPriority(_Cmd):
     def action(self, groups, cfg, params):
         priority = groups["priority"]
 
-        cfg_stp_pri = cfg.setdefault("stp-priority", {})
+        cfg_stp_pri = cfg.setdefault("spanning-tree-vlan-priority", {})
         for tag in _expand_set(groups["tags"]):
             cfg_stp_pri[int(tag)] = int(priority)
 
@@ -1044,7 +1059,7 @@ class CiscoIOSConfig(IndentedContextualConfig):
         # go through the pending IPv4 standard ACLs and store them (we
         # convert this to a list as _acl4_std_flush() will change the
         # dictionary during iteration and we only need the names)
-        if "ip-acl-std" in self:
-            ip_acl_std = self["ip-acl-std"]
+        if "ip-access-list-standard" in self:
+            ip_acl_std = self["ip-access-list-standard"]
             for name in ip_acl_std:
                 ip_acl_std[name] = _ipacl_std_canonicalize(ip_acl_std[name])
